from setuptools import setup

setup(
    name='Aditzak',
    version='0.3.20',    
    description='A Python package to analyse and build Euskera/Basque verbs.',
    url='https://github.com/HCook86/Aditzak/',
    author='',
    author_email='aditzaksoftware@gmail.com',
    license='BSD 2-clause',
    packages=['Aditzak'],
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',  
        'Operating System :: OS Independent',
        "Programming Language :: Python :: 3"
    ],
    include_package_data=True
)